<?php
/*
  Plugin Name: FloeComment
  Plugin URI: http://floecomment.floesub.com
  Description: Manage posted comments by rules. DoFollow, by characters number, by comments count. You can set the rules and the syntax to post dofollow comments.
  Version: 1.0
  Author: Floesub Team
  Author URI: https://twitter.com/floesub
*/
if(function_exists('load_plugin_textdomain')) load_plugin_textdomain( 'floecomment', basename(dirname(__FILE__)).'/languages', basename(dirname(__FILE__)).'/languages');

$options = get_option('floecomment_options');

if(!array_key_exists('library', $options) || $options['library']=='countablejs') wp_enqueue_script( 'countable-js', plugin_dir_url(__FILE__).'js/Countable.js', array('jquery'), 1.0);

/* admin section */
if(is_admin()) {
  add_action('admin_menu', 'floecomment_admin');
  
  /*
   * floecomment_admin() function
   * set the admin settings panel
  */
  
  function floecomment_admin()
  {
    if(function_exists('add_options_page')) add_options_page('FloeComment rules', 'FloeComment', 'update_plugins', basename(__FILE__), 'floecomment_rules_form');
  }
  
  /*
   * floecomment_rules_form() function
   * admin settings form
  */

  function floecomment_rules_form()
  {
    $options = get_option('floecomment_options');
    // store options if post
    if(array_key_exists('post_is', $_POST)){
      $options = array('message'=>$_POST['floecomment_message'],'separator'=>$_POST['floecomment_separator'],'characters'=>$_POST['floecomment_characters'],'count'=>$_POST['floecomment_count'],'words'=>$_POST['floecomment_words'],'display'=>$_POST['floecomment_display'],'library'=>$_POST['floecomment_library']);
      update_option('floecomment_options', $options);
    }

    ?>
    <div class="wrap">
      <?php screen_icon(); ?>
      <h2><?php echo esc_html(__('FloeComment settings', 'floecomment')); ?></h2>
      <form method="post" action="">
        <input type="hidden" name="post_is" value="1" />
        <table class="form-table">
          <tr valign="top">
            <th scope="row"><label for="floecomment_characters"><?php echo __('Characters', 'floecomment') ?></label></th>
            <td>
              <input name="floecomment_characters" id="floecomment_characters" type="text" value="<?php echo $options['characters'] ?>" class="small-text">
              <p class="description"><?php _e('Minimum of characters in the comment to get a dofollow link.', 'floecomment') ?></p>
            </td>
          </tr>
          <tr valign="top">
            <th scope="row"><label for="floecomment_words"><?php echo __('Words', 'floecomment') ?></label></th>
            <td>
              <input name="floecomment_words" id="floecomment_words" type="text" value="<?php echo $options['words'] ?>" class="small-text">
              <p class="description"><?php _e('Minimum of words in the comment to get dofollow link.', 'floecomment') ?></p>
            </td>
          </tr>
          <tr valign="top">
            <th scope="row"><label for="floecomment_count"><?php echo __('Count', 'floecomment') ?></label></th>
            <td>
              <input name="floecomment_count" id="floecomment_count" type="text" value="<?php echo $options['count'] ?>" class="small-text">
              <p class="description"><?php _e('Minimum of comments by visitor to get dofollow link.', 'floecomment') ?></p>
            </td>
          </tr>
          <tr valign="top">
            <th scope="row"><label for="floecomment_separator"><?php echo __('Separator', 'floecomment') ?></label></th>
            <td>
              <input name="floecomment_separator" id="floecomment_separator" type="text" value="<?php echo $options['separator'] ?>" class="small-text">
              <p class="description"><?php _e('You can choice the separator to explode the name and the website. It may be name@anchor, name#anchor, name%by%anchor.', 'floecomment') ?></p>
            </td>
          </tr>
          <tr valign="top">
            <th scope="row"><label for="floecomment_display"><?php echo __('Display', 'floecomment') ?></label></th>
            <td>
              <input name="floecomment_display" id="floecomment_display" type="text" value="<?php echo $options['display'] ?>" class="regular-text">
              <p class="description"><?php _e('Displaying rules for author and website. Examples : %author% from %url% - %author% bought to you by %url% - %author% provides %url%', 'floecomment') ?></p>
            </td>
          </tr>
          <tr valign="top">
            <th scope="row"><label for="floecomment_message"><?php echo __('Message', 'floecomment') ?></label></th>
            <td>
              <textarea name="floecomment_message" id="floecomment_message" rows="4" cols="80" class="code"><?php echo stripslashes($options['message']) ?></textarea>
              <p class="description"><?php _e('You can set the message show after the comment form. HTML is enabled.', 'floecomment') ?></p>
              <p class="description"><?php _e('You can use variables like : %separator% - %characters% - %words% - %count% - %floecomment% which will be automaticaly replaced.', 'floecomment') ?></p>
              <p class="description"><?php _e('Examples : "Try to enter nickname#anchor to get a dofollow backlink" - "Entering nickname%from%anchor enables you to have a flavoured backlink."', 'floecomment') ?></p>
            </td>
          </tr>
          <tr valign="top">
            <th scope="row"><label for="floecomment_library"><?php echo __('Counter library', 'floecomment') ?></label></th>
            <td>
              <fieldset><legend class="screen-reader-text"><span>Format de date</span></legend>
              	<label title="<?php _e('None', 'floecomment') ?>"><input type="radio" name="floecomment_library" value="none"<?php if(array_key_exists('library', $options) && $options['library']=='none'): echo ' checked="checked"'; endif;?>> <span><?php _e('None', 'floecomment') ?></span></label><br />
              	<label title="<?php echo 'Countable JS' ?>"><input type="radio" name="floecomment_library" value="countablejs"<?php if(!array_key_exists('library', $options) || $options['library']=='countablejs'): echo ' checked="checked"'; endif;?>> <span><?php echo 'Countable JS' ?></span></label><br />
              	</fieldset>
            </td>
          </tr>
          
          
        </table>
        <?php submit_button(); ?>
      </form>
    </div>
    <?php
  }
}

/* frontend section */

/*
 * floecomment_form() function
 * add information around comment guest form
*/

function floecomment_form()
{
  $default = __('This blog uses %floecomment%, try nickname%separator%anchor to get a dofollow backlink.', 'floecomment');
  $options = get_option('floecomment_options');
  if(!array_key_exists('library', $options) || $options['library']=='countablejs'){
    echo '<p id="counter"></p>';
    echo "<script>jQuery(document).ready(function() {
      Countable.live(document.getElementById('comment'), function (counter) {
      jQuery('#counter').html('".__('Characters', 'floecomment')." : '+counter.characters+' - ".__('Words', 'floecomment')." : '+counter.words);
    })
    });
    </script>";
  }
  if((array_key_exists('characters', $options) && $options['characters']) || (array_key_exists('words', $options) && $options['words']) || (array_key_exists('count', $options) && $options['count'])){
    $rules = array();
    if($options['characters']) $rules[] = $options['characters'].' '.__('characters min', 'floecomment');
    if($options['words']) $rules[] = $options['words'].' '.__('words min', 'floecomment');
    if($options['count']) $rules[] = $options['count'].' '.__('comments min', 'floecomment');
    $default.= '<br />'.__('Rules are : ', 'floecomment').implode(', ', $rules).'.';
  }
  $replacements = array(
    '`%separator%`' => array_key_exists('separator', $options) ? $options['separator'] : '#',
    '`%characters%`' => array_key_exists('characters', $options) ? $options['characters'] : null,
    '`%words%`' => array_key_exists('words', $options) ? $options['words'] : null,
    '`%count%`' => array_key_exists('count', $options) ? $options['count'] : null,
    '`%floecomment%`' => '<a href="http://floecomment.floesub.com">FloeComment</a>',
  );
  $message = preg_replace(array_keys($replacements), array_values($replacements), array_key_exists('message', $options) && $options['message'] ? $options['message'] : $default);
  echo '<p>'.html_entity_decode(stripslashes($message)).'</p>';
}

/*
 * floecomment_groupby() function
 * Filter if rule comments by user count is set
*/

function floecomment_groupby( $groupby) {
    global $wpdb;
    $groupby = "{$wpdb->comments}.COMMENT_AUTHOR_EMAIL";
    return $groupby;
}

/*
 * floeDofollow() function
 * remove dofollow attibute on <a> tag
*/

function floeDofollow($text = ''){
  $patterns = array(
    '`rel=nofollow`' => null,
    '` nofollow`' => null,
  );
  
  return preg_replace(array_keys($patterns), array_values($patterns), $text);
}

/*
 * floecomment_isnorules() function
 * check if any rule is set
*/

function floecomment_isnorules($options = array())
{
  if((!array_key_exists('characters', $options) || $options['characters']==null) && (!array_key_exists('words', $options) || $options['words']==null) && (!array_key_exists('count', $options) || $options['count']==null)) return true;
  return false;
}

/*
 * floecomment_filters() function
 * apply each filter on author and link
*/
function floecomment_filters($text = '')
{
  $options = get_option('floecomment_options');
  $doFollow = false;
  if(array_key_exists('characters', $options) && (int)$options['characters']>0 && mb_strlen(get_comment_text(),'utf-8')>=(int)$options['characters']) $doFollow = true;
  
  if(array_key_exists('words', $options) && (int)$options['words']>0 && count(explode(' ', get_comment_text()))>=(int)$options['words']) $doFollow = true;
  
  if(array_key_exists('count', $options) && (int)$options['count']>0){
    $comment = get_comment($comment_ID);
    if($userId = $comment->user_id){
      $commentCount = get_comments(array('user_id' => $userId, 'count' => true));
      if($commentCount>=(int)$options['count']) $doFollow = true;
    } else {
      $commentCount = get_comments(array('author_email'=>get_comment_author_email(), 'count' => true));
      if($commentCount>=(int)$options['count']) $doFollow = true;
    }
    
  }
  
  if(floecomment_isnorules($options)) $doFollow = true;
  
  if($doFollow) add_filter('get_comment_author_link', 'floeDofollow', 12);
  else remove_filter('get_comment_author_link', 'floeDofollow', 12);
  
  if(array_key_exists('separator', $options) && $options['separator']) $seprator = $options['separator'];
  else $seprator = '#';
  
  if(preg_match('`'.$seprator.'`', ($commentAuthor = get_comment_author()))){
    $explode = explode($seprator, $commentAuthor);
    $commentAuthor = $explode[0];
    $commentLink = $explode[1];
    $commentWebsite = preg_replace('`'.$commentAuthor.$seprator.'`', null, $text);
    $text = (array_key_exists('display', $options) && $options['display']) ? preg_replace(array('`%author%`','`%url%`'), array($commentAuthor, $commentWebsite), $options['display']) : $commentAuthor.' '.__('from', 'floecomment').' '.$commentWebsite;
  }
  
  return $text;
}

add_action('comment_form', 'floecomment_form');
add_action('get_comment_author_link', 'floecomment_filters');

?>